==> haskell-selective-0.6-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 selective
version:              0.6
visibility:           public
id:                   selective-0.6-ExgKyvQj4mqLXnQpD3e8qx
key:                  selective-0.6-ExgKyvQj4mqLXnQpD3e8qx
license:              MIT
copyright:            Andrey Mokhov, 2018-2023
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.

category:             Control
abi:                  576b2fe786c73d89d419bd9e14df5515
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.2.8/site-local/selective-0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/selective-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.6-ExgKyvQj4mqLXnQpD3e8qx
depends:              base-4.16.4.0 containers-0.6.5.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-selective-0.6-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 selective
version:              0.6
visibility:           public
id:                   selective-0.6-DpglevUm19W4wxdcH8ec2n
key:                  selective-0.6-DpglevUm19W4wxdcH8ec2n
license:              MIT
copyright:            Andrey Mokhov, 2018-2023
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.

category:             Control
abi:                  6b27624414bafe24ae8df73ca46451ac
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.2.8/site-local/selective-0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/selective-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.6-DpglevUm19W4wxdcH8ec2n
depends:              base-4.16.4.0 containers-0.6.5.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
